@@ -1331,8 +1331,12 @@ RObject lambda3(RObject& mpm, Nullable<RObject> force_sparse = R_NilValue) {
           arma::vec chosen_eigvals = all_eigenvalues.elem(max_elems);
           arma::uvec pos_max_eigvals = find(chosen_eigvals > 0);
           
-          lambda_prog(i) = chosen_eigvals(pos_max_eigvals(0));
-          
+          if (pos_max_eigvals.n_elem > 0) {
+            lambda_prog(i) = chosen_eigvals(pos_max_eigvals(0));
+          } else {
+            lambda_prog(i) = 0.0;
+            Rf_warningcall(R_NilValue, "A matrix with an eigenvalue of 0 has been detected.");
+          }
         } else {
           arma::sp_mat spAmat;
           
@@ -1358,8 +1362,12 @@ RObject lambda3(RObject& mpm, Nullable<RObject> force_sparse = R_NilValue) {
           arma::vec chosen_eigvals = all_eigenvalues.elem(max_elems);
           arma::uvec pos_max_eigvals = find(chosen_eigvals > 0);
           
-          if (pos_max_eigvals.n_elem > 0) lambda_prog(i) = chosen_eigvals(pos_max_eigvals(0));
-          
+          if (pos_max_eigvals.n_elem > 0) {
+            lambda_prog(i) = chosen_eigvals(pos_max_eigvals(0));
+          } else {
+            lambda_prog(i) = 0.0;
+            Rf_warningcall(R_NilValue, "A matrix with an eigenvalue of 0 has been detected.");
+          }
         }
       }
       output = lambda_prog;
@@ -1422,8 +1430,12 @@ RObject lambda3(RObject& mpm, Nullable<RObject> force_sparse = R_NilValue) {
           arma::vec chosen_eigvals = all_eigenvalues.elem(max_elems);
           arma::uvec pos_max_eigvals = find(chosen_eigvals > 0);
           
-          lambda_prog(i) = chosen_eigvals(pos_max_eigvals(0));
-          
+          if (pos_max_eigvals.n_elem > 0) {
+            lambda_prog(i) = chosen_eigvals(pos_max_eigvals(0));
+          } else {
+            lambda_prog(i) = 0.0;
+            Rf_warningcall(R_NilValue, "A matrix with an eigenvalue of 0 has been detected.");
+          }
         } else {
           arma::sp_mat spAmat;
           
@@ -1451,6 +1463,9 @@ RObject lambda3(RObject& mpm, Nullable<RObject> force_sparse = R_NilValue) {
           
           if (pos_max_eigvals.n_elem > 0) {
             lambda_prog(i) = chosen_eigvals(pos_max_eigvals(0));
+          } else {
+            lambda_prog(i) = 0.0;
+            Rf_warningcall(R_NilValue, "A matrix with an eigenvalue of 0 has been detected.");
           }
         }
       }
@@ -1516,8 +1531,12 @@ RObject lambda3(RObject& mpm, Nullable<RObject> force_sparse = R_NilValue) {
       arma::vec chosen_eigvals = all_eigenvalues.elem(max_elems);
       arma::uvec pos_max_eigvals = find(chosen_eigvals > 0);
       
-      lambda_prog(0) = chosen_eigvals(pos_max_eigvals(0));
-      
+      if (pos_max_eigvals.n_elem > 0) {
+        lambda_prog(0) = chosen_eigvals(pos_max_eigvals(0));
+      } else {
+        lambda_prog(0) = 0.0;
+        Rf_warningcall(R_NilValue, "A matrix with an eigenvalue of 0 has been detected.");
+      }
     } else {
       arma::sp_mat spAmat(mpm_);
       
@@ -1538,7 +1557,12 @@ RObject lambda3(RObject& mpm, Nullable<RObject> force_sparse = R_NilValue) {
       arma::vec chosen_eigvals = all_eigenvalues.elem(max_elems);
       arma::uvec pos_max_eigvals = find(chosen_eigvals > 0);
       
-      if (pos_max_eigvals.n_elem > 0) lambda_prog(0) = chosen_eigvals(pos_max_eigvals(0));
+      if (pos_max_eigvals.n_elem > 0) {
+        lambda_prog(0) = chosen_eigvals(pos_max_eigvals(0));
+      } else {
+        lambda_prog(0) = 0.0;
+        Rf_warningcall(R_NilValue, "A matrix with an eigenvalue of 0 has been detected.");
+      }
     }
     
     output = lambda_prog;
@@ -1566,7 +1590,12 @@ RObject lambda3(RObject& mpm, Nullable<RObject> force_sparse = R_NilValue) {
     arma::vec chosen_eigvals = all_eigenvalues.elem(max_elems);
     arma::uvec pos_max_eigvals = find(chosen_eigvals > 0);
     
-    if (pos_max_eigvals.n_elem > 0) lambda_prog(0) = chosen_eigvals(pos_max_eigvals(0));
+    if (pos_max_eigvals.n_elem > 0) {
+      lambda_prog(0) = chosen_eigvals(pos_max_eigvals(0));
+    } else {
+      lambda_prog(0) = 0.0;
+      Rf_warningcall(R_NilValue, "A matrix with an eigenvalue of 0 has been detected.");
+    }
     
     output = lambda_prog;
     
